==> haskell-constraints-extras-0.4.0.1-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 constraints-extras
version:              0.4.0.1
visibility:           public
id:                   constraints-extras-0.4.0.1-DafcfTci4WQFVsOXfct9Xo
key:                  constraints-extras-0.4.0.1-DafcfTci4WQFVsOXfct9Xo
license:              BSD-3-Clause
copyright:            Obsidian Systems LLC
maintainer:           maintainer@obsidian.systems
author:               Cale Gibbard, Ali Abrar
homepage:             https://github.com/obsidiansystems/constraints-extras
synopsis:             Utility package for constraints
description:
    Convenience functions and TH for working with constraints. See <https://github.com/obsidiansystems/constraints-extras/blob/develop/README.md README.md> for example usage.

category:             Constraints
abi:                  281c081ac0aaad52a59d643cbe0ac238
exposed:              True
exposed-modules:
    Data.Constraint.Compose Data.Constraint.Extras
    Data.Constraint.Extras.TH Data.Constraint.Flip

import-dirs:          /usr/lib/ghc-9.4.8/site-local/constraints-extras-0.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/constraints-extras-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/constraints-extras-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints-extras
hs-libraries:         HSconstraints-extras-0.4.0.1-DafcfTci4WQFVsOXfct9Xo
depends:
    base-4.17.2.1 constraints-0.13.4-5Blb8c1F1RUBmVAEMt4hYe
    template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-constraints-extras/html/constraints-extras.haddock

haddock-html:         /usr/share/doc/haskell-constraints-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-constraints-extras-0.4.0.1-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 constraints-extras
version:              0.4.0.1
visibility:           public
id:                   constraints-extras-0.4.0.1-5g5dPMVIcno5yOYc483zLL
key:                  constraints-extras-0.4.0.1-5g5dPMVIcno5yOYc483zLL
license:              BSD-3-Clause
copyright:            Obsidian Systems LLC
maintainer:           maintainer@obsidian.systems
author:               Cale Gibbard, Ali Abrar
homepage:             https://github.com/obsidiansystems/constraints-extras
synopsis:             Utility package for constraints
description:
    Convenience functions and TH for working with constraints. See <https://github.com/obsidiansystems/constraints-extras/blob/develop/README.md README.md> for example usage.

category:             Constraints
abi:                  ecc7bf75eba83baa31778b41414ece51
exposed:              True
exposed-modules:
    Data.Constraint.Compose Data.Constraint.Extras
    Data.Constraint.Extras.TH Data.Constraint.Flip

import-dirs:          /usr/lib/ghc-9.4.8/site-local/constraints-extras-0.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/constraints-extras-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/constraints-extras-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints-extras
hs-libraries:         HSconstraints-extras-0.4.0.1-5g5dPMVIcno5yOYc483zLL
depends:
    base-4.17.2.1 constraints-0.13.4-1xj9UKETYQ82ccfPkGqejf
    template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-constraints-extras/html/constraints-extras.haddock

haddock-html:         /usr/share/doc/haskell-constraints-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
